@@ -15,7 +15,6 @@ class FormatterBase(object):
 
     defaults = {} # default values for attrs to be set on the instance
     
-
     def __init__(self, string):
         args = [ i.strip() for i in string.split(',')]
         for index, arg in enumerate(args):
@@ -36,8 +35,11 @@ class FormatterBase(object):
 ### formatters
 
 class Ignore(object):
-    """ignore files of a certain pattern"""
-    
+    """
+    ignore files of a glob patterns.  
+    These files will not be linked to in the template.
+    e.g. /ignore = .* *.pdf  # don't list dotfiles and PDFs
+    """
 
     def __init__(self, ignore):
         self.match = ignore.split()
@@ -62,7 +64,6 @@ class All(object):
     
     def __init__(self, pattern):
         self.match = pattern.split()
-        
 
     def __call__(self, request, data):
         _files = []
@@ -79,7 +80,11 @@ class All(object):
         data['files'] = _files
         
 class Sort(object):
-    """ determines how to sort the files in a directory """
+    """
+    determines how to sort the files in a directory; 
+    right now only by case-insensitive alphabetically
+    * reverse : reverse the order of the sorting
+    """
     def __init__(self, pattern):
         self.args = [i.strip() for i in pattern.split(',')]
     
@@ -92,13 +97,19 @@ class Sort(object):
     
 
 class FilenameDescription(FormatterBase):
-    """substitute the description for the filename"""
+    """
+    obtain the description from the filename
+    the file extension (if any) will be dropped and
+    spaces will be substituted for underscores
+    """
+    # TODO : deal with CamelCaseFilenames
 
     def __call__(self, request, data):
         for f in data['files']:
             if f['description'] is None:
                 description = f['name']
-                description = description.rsplit('.', 1)[0]
+                if '.' in description:
+                    description = description.rsplit('.', 1)[0]
                 decription = description.strip('_')
                 if '_' in description:
                     description = ' '.join([i.title() for i in description.split('_')])
@@ -106,8 +117,14 @@ class FilenameDescription(FormatterBase):
 
 
 class TitleDescription(FormatterBase):
-    """splits a description into a title and a description with a separator"""
-    
+    """
+    splits a description into a title and a description via a separator in 
+    the description.  The template will now have an additional variable, 
+    'title', per file
+    Arguments:
+    * separator: what separator to use (':' by default)
+    """
+    # XXX what about setting the page title?
 
     defaults = { 'separator': ':' }
         
@@ -121,14 +138,48 @@ class TitleDescription(FormatterBase):
                 f['title'] = f['description']
                 f['description'] = None
 
+class Links(FormatterBase):
+    """
+    allow list of links per item:
+    foo.html = description of foo; [PDF]=foo.pdf; [TXT]=foo.txt
+    """
+    
+    defaults = { 'separator': ';' }
+
+    def __call__(self, request, data):
+        for f in data['files']:
+            if f['description'] and self.separator in f['description']:
+                f['description'], links = f['description'].split(self.separator, 1)
+                links = links.split(self.separator)
+                assert min(['=' in link for link in links])
+                links = [ link.split('=', 1) for link in links ]
+                f['links'] = [ { 'text': text, 'link': link }
+                             for text, link in links ]
+
 class CSS(object):
-    """specify CSS"""
+    """specify CSS used (whitespace separated list)"""
 
     def __init__(self, arg):
         self.css = arg.split()
     def __call__(self, request, data):
         data['css'] = self.css
 
+class JavaScript(object):
+    """specify JS for the page"""
+
+    def __init__(self, arg):
+        self.scripts = arg.split()
+    def __call__(self, request, data):
+        data['scripts'] = self.scripts
+
+class Favicon(object):
+    """specify favicons for the page"""
+
+    def __init__(self, icon):
+        self.icon = icon
+    def __call__(self, request, data):
+        data['icon'] = self.icon
+
 class Include(object):
     """include a file at the top of the body"""
 
