@@ -1,5 +1,5 @@
 """
-decoupage: a view with webob
+decoupage: a view with webob to index and serve static content
 """
 
 import os
@@ -40,7 +40,9 @@ class Decoupage(object):
         self.directory = self.directory.rstrip(os.path.sep)
         assert os.path.isdir(self.directory)
         self.template_directories = self.template_directories.split() # no spaces in directory names, for now
-        assert sum([os.path.isdir(directory) for directory in self.template_directories]) == len(self.template_directories)
+
+        for directory in self.template_directories:
+            assert os.path.isdir(directory), "Decoupage template directory %s does not exist!" % directory
 
         # static file server
         self.fileserver = FileApp
@@ -102,13 +104,17 @@ class Decoupage(object):
         # get the configuraton
         conf = self.conf(path)
 
-        # build data dictionary
+        ### build data dictionary
         files = self.filedata(path, directory, conf)
         data = {'path': path, 'files': files, 'request': request }
+
+        # defaults; TODO: make this better
         data['title'] = conf.get('/title')
         data['directory'] = directory
         data['include'] = None
         data['css'] = ()
+        data['scripts'] = ()
+        data['icon'] = None
 
         # apply formatters
         # XXX this should be cached if not self.auto_reload
